"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeWebview = require("react-native-webview");

/**
 * StripeIdentityWebView
 *
 * Handles a full Stripe Identity journey on react native via webview
 *
 * Important Notes about URLs:
 * - successUrl must have the query string params `?vi={VERIFICATION_INTENT_ID}`
 *   - vi must be the last param - passed to the onSuccess function as verificationIntentId
 *
 */
const StripeIdentityWebView = props => {
  const {
    redirectToUrl,
    refreshUrl,
    onSuccess,
    onRefresh,
    onLoadingComplete,
    webViewProps = {},
    renderOnComplete
  } = props;
  /** Holds the complete URL if exists */

  const [completed, setCompleted] = (0, _react.useState)(null);
  /** Holds wether Stripe Identity has loaded yet */

  const [hasLoaded, setHasLoaded] = (0, _react.useState)(false);
  /**
   * Called every time the URL stats to load in the webview
   *
   * handles completing the identity session
   */

  const _onLoadStart = syntheticEvent => {
    const {
      nativeEvent
    } = syntheticEvent;
    const {
      url: currentUrl
    } = nativeEvent;
    /** Check and handle identity state: success */

    if (currentUrl.includes('?vi=') || currentUrl.includes('&vi=')) {
      const verificationIntentIdKey = 'vi=';
      const verificationIntentId = currentUrl.substring(currentUrl.indexOf(verificationIntentIdKey), currentUrl.length)
      /** remove key */
      .replace(verificationIntentIdKey, '')
      /** remove extra trailing slash */
      .replace('/', '');
      setCompleted(true);

      if (onSuccess) {
        onSuccess({ ...props,
          verificationIntentId
        });
      }

      return;
    }
    /** Check and handle identity state: refresh */


    if (currentUrl === refreshUrl) {
      setCompleted(true);

      if (onRefresh) {
        onRefresh(props);
      }
    }
    /** call webViewProps.onLoadStart */


    if (webViewProps && webViewProps.onLoadStart) {
      webViewProps.onLoadStart(syntheticEvent);
    }
  };
  /**
   * Called upon URL load complete
   */


  const _onLoadEnd = syntheticEvent => {
    const {
      nativeEvent
    } = syntheticEvent;
    /** set isLoading to false once the stripe identity page loads */

    if (!hasLoaded && nativeEvent.url.startsWith('https://verify.stripe.com') && onLoadingComplete) {
      setHasLoaded(true);
      onLoadingComplete(syntheticEvent);
    }
    /** call webViewProps.onLoadStart */


    if (webViewProps && webViewProps.onLoadEnd) {
      webViewProps.onLoadEnd(syntheticEvent);
    }
  };
  /** If the identity session is complete -- render the complete content */


  if (completed) {
    return renderOnComplete ? renderOnComplete({
      url: completed,
      ...props
    }) : /*#__PURE__*/_react.default.createElement(_reactNative.Text, null, "Stripe Identity session complete.");
  }
  /** Render the WebView holding the Stripe identity flow */


  return /*#__PURE__*/_react.default.createElement(_reactNativeWebview.WebView
  /** pass baseUrl to avoid  `IntegrationError: Live Stripe.js integrations must use HTTPS.` error https://github.com/react-native-community/react-native-webview/issues/1317 */
  , (0, _extends2.default)({
    baseUrl: "",
    originWhitelist: ['*']
  }, webViewProps, {
    source: {
      uri: redirectToUrl
    },
    onLoadStart: _onLoadStart,
    onLoadEnd: _onLoadEnd
  }));
};

var _default = StripeIdentityWebView;
exports.default = _default;
//# sourceMappingURL=StripeIdentity.js.map